@@ -6,6 +6,7 @@ import click
 import coloredlogs
 
 from neoload_cli_lib import tools, rest_crud, cli_exception
+from neoload_cli_lib.cli_exception import CliException
 
 import urllib3
 
@@ -61,4 +62,12 @@ def cli(debug, batch):
 
 
 if __name__ == '__main__':
-    cli()
+    try:
+        cli()
+    except CliException as ex:
+        print(ex.format_message(), file = sys.stderr)
+    except Exception as ex:
+        if cli_exception.CliException.is_debug():
+            raise ex
+        else:
+            print(ex.__str__(), file=sys.stderr)
