@@ -1,19 +1,28 @@
 import click
 
 from commands import test_results
-from neoload_cli_lib import displayer, running_tools, tools
+from neoload_cli_lib import displayer, running_tools, tools, rest_crud
 from datetime import datetime, date
 import time
 import sys
+import subprocess
+import yaml
+import logging
 
 @click.command()
 @click.argument('command', type=click.Choice(['slas'], case_sensitive=False))
 @click.argument("name", type=str, required=False)
-@click.option("--stop", 'stop', is_flag=True, default=True, help="Doesn't wait the end of test")
-@click.option("--force", 'force', is_flag=True, default=True, help="Doesn't wait the end of test")
-@click.option("--max-failure", 'max_failure', type=int, default=0, help="Max SLA failure threshold; default is zero")
-def cli(command, name, stop, force, max_failure): #, max_occurs):
+@click.option("--stop", 'stop', is_flag=True, default=True,
+              help="Stop the running test if slas threshold is reached. default is True")
+@click.option("--force", 'force', is_flag=True, default=True,
+              help="Immediately kill Load Generators and do not apply the stop policy. Some statistics may be wrong. default is True")
+@click.option("--max-failure", 'max_failure', type=int, default=0,
+              help="Max SLA percentage failure threshold; default is zero")
+@click.option("--stop-command", 'stop_command', required=False,
+              help="System command that will be executed instead of stopping NLW test. Optional.")
+def cli(command, name, stop, force, max_failure, stop_command): #, max_occurs):
     """Fails if certain conditions are met, such as per-run SLAs failed % of time"""
+    rest_crud.set_current_command()
     if not command:
         tools.system_exit({'message': "command is mandatory. Please see neoload fastfail --help", 'code': 2})
         return
@@ -29,12 +38,12 @@ def cli(command, name, stop, force, max_failure): #, max_occurs):
         return
 
     if command == "slas":
-        monitor_loop(__id, stop, force, max_failure)
+        monitor_loop(__id, stop, force, max_failure, stop_command)
 
     else:
         tools.system_exit({'message': "Invalid command. Please see neoload fastfail --help", 'code': 2})
 
-def monitor_loop(__id, stop, force, max_failure):
+def monitor_loop(__id, stop, force, max_failure, stop_command):
     dt_started = datetime.now()
     print('fastfail started: ' + str(dt_started))
     dt_current = dt_started
@@ -47,7 +56,8 @@ def monitor_loop(__id, stop, force, max_failure):
     has_exited = False
     msg = ""
     exit_code = 0
-    while (abs(dt_current-dt_started).seconds / 60) < 10:
+    mins_worst_case = get_duration_mins_by_result(__id)
+    while (abs(dt_current-dt_started).seconds / 60) < mins_worst_case:
         datas = test_results.get_sla_data_by_name_or_id(__id)
 
         partial_intervals = list(filter(lambda x: x['status']=='FAILED',datas['sla_interval']))
@@ -65,7 +75,13 @@ def monitor_loop(__id, stop, force, max_failure):
         if len(partial_intervals) > 0 and len(failed_intervals) < 1:
             msg += "\nSome SLAs failed, but were not above max-failure of {0}% so did not count as error.".format(max_failure)
 
-        outcomes = process_state(datas,fails,stop,force,is_initializing,is_running,msg)
+        fail_options = {
+            'stop': stop,
+            'force': force,
+            'stop_command': stop_command
+        }
+
+        outcomes = process_state(datas,fails,fail_options,is_initializing,is_running)
 
         final_run = has_exited and outcomes["has_exited"]
         has_exited = outcomes["has_exited"]
@@ -73,13 +89,12 @@ def monitor_loop(__id, stop, force, max_failure):
         is_running = outcomes["is_running"]
         exit_code = 0 if datas['result']['qualityStatus']=="PASSED" else 1
 
-        if final_run:
-            break
-        elif (len(fails) > 0 or len(partial_intervals) > 0):
-            displayer.__print_sla(datas['sla_global'], datas['sla_test'], datas['sla_interval'])
+        should_continue = monitor_loop_check(datas,fails,partial_intervals,final_run,has_exited,exit_code)
+        if should_continue:
+            if not has_exited:
+                time.sleep(15)
         else:
-            printif(sys.stdin.isatty() and not has_exited, '.', end = '')
-            time.sleep(15)
+            break
 
         dt_current = datetime.now()
 
@@ -91,7 +106,41 @@ def monitor_loop(__id, stop, force, max_failure):
 
     tools.system_exit({'message': msg, 'code': exit_code})
 
-def process_state(datas,fails,stop,force,is_initializing,is_running,msg):
+def monitor_loop_check(datas,fails,partial_intervals,final_run,has_exited,exit_code):
+    should_continue = True
+
+    if final_run:
+        debugmsg = ""
+        if exit_code!=0:
+            debugmsg = "fastfail[results]: exit_code={} is a result of datas: {}".format(exit_code,yaml.dump(datas))
+            logging.debug(debugmsg)
+        should_continue = False
+    else:
+        if (len(fails) > 0 or len(partial_intervals) > 0):
+            failed_global = list(filter(lambda x: 'status' in x and x['status'] == 'FAILED', datas['sla_global']))
+            failed_test = list(filter(lambda x: 'status' in x and x['status'] == 'FAILED', datas['sla_test']))
+            failed_interval = list(filter(lambda x: 'status' in x and x['status'] == 'FAILED', datas['sla_interval']))
+            displayer.__print_sla(failed_global, failed_test, failed_interval)
+        else:
+            printif(sys.stdin.isatty() and not has_exited, '.', end = '')
+
+    return should_continue
+
+def get_duration_mins_by_result(__id):
+
+    ret = (60 * 4) # initial default, if results -> settings -> project
+    #summary = test_results.get_json_summary(__id)["summary"]
+    #if 'testId' in summary
+
+    #rest_crud.get_from_file_storage(get_endpoint(setting_id))
+    return ret
+
+def process_state(datas,fails,fail_options,is_initializing,is_running):
+
+    stop = fail_options['stop']
+    force = fail_options['force']
+    stop_command = fail_options['stop_command']
+
     ret = {
         "has_exited": False,
         "is_initializing": is_initializing,
@@ -101,6 +150,11 @@ def process_state(datas,fails,stop,force,is_initializing,is_running,msg):
 
     if len(fails) > 0:
         if status != 'TERMINATED' and stop:
+            if stop_command is not None:
+                out = subprocess.run(stop_command, shell=True, capture_output=True)
+                print(f"\nStopping test with the system command {out.args}\n - return code={out.returncode}")
+                print(f" - stdout={out.stdout}\n - stderr={out.stderr}")
+            else:
                 print("\nStopping test, force={0}".format(force))
                 tools.set_batch(True)
                 running_tools.stop(datas["id"], force)
