@@ -9,7 +9,7 @@ from neoload_cli_lib import rest_crud, tools, cli_exception
 import shutil
 
 not_to_be_included = ['recorded-requests/', 'recorded-responses/', 'recorded-screenshots/', '.git/', '.svn/',
-                      'results/',
+                      'results/','.config/',
                       'comparative-summary/', 'reports/', '/recorded-artifacts/']
 
 
@@ -25,19 +25,29 @@ def is_not_to_be_included(path: str, nl_ignore_matcher):
 
 
 def zip_dir(path,save):
-
     # validate save parameter, if provided, is a zip
     if save is not None:
         save = os.path.abspath(save)
         if not save.endswith(".zip"):
             raise cli_exception.CliException('If you specify where to save the zip file, it must end with .zip')
+        file_stream = open(save, "w+b")
+    else:
+        # always to work in a separate file, if save is provided, or otherwise
+        file_stream = tempfile.NamedTemporaryFile('w+b')
 
     # find and load .nlignore
     ignore_file = os.path.join(path, '.nlignore')
     nl_ignore_matcher = parse_gitignore(ignore_file) if os.path.exists(ignore_file) else None
 
-    # always to work in a separate file, if save is provided, or otherwise
-    temp_zip = tempfile.NamedTemporaryFile('w+b',delete=False)
+    compress_project(nl_ignore_matcher, path, file_stream)
+
+    # always ensure that stream starts at beginning
+    file_stream.seek(0)
+
+    return file_stream
+
+
+def compress_project(nl_ignore_matcher, path, temp_zip):
     ziph = zipfile.ZipFile(temp_zip, 'x', zipfile.ZIP_DEFLATED)
     for root, dirs, files in os.walk(path):
         for file in files:
@@ -46,27 +56,11 @@ def zip_dir(path,save):
                 ziph.write(file_path, file_path.replace(str(path), ''))
     ziph.close()
 
-    # by default we return the temp file
-    file_stream = temp_zip
-
-    # if save file specified, copy temp to the specified save file
-    if save is not None:
-        # only delete the specified save if temp was created
-        temp_zip.close()
-        shutil.move(temp_zip.name, save)
-        # return an open file stream to the new file specified by save
-        file_stream = open(save)
-
-    # always ensure that stream starts at beginning
-    file_stream.seek(0)
-
-    return file_stream
-
 
 def upload_project(path, endpoint, save=None):
     filename = os.path.basename(path)
     if str(path).endswith(('.zip', '.yaml', '.yml')):
-        file = open(path, "b+r")
+        file = open(path, "br")
     else:
         filename += '.zip'
         file = zip_dir(path,save)
