@@ -2,14 +2,16 @@ import pytest
 from types import SimpleNamespace
 from _pytest.main import Session
 from click.testing import CliRunner
+
+import sys
+sys.path.append('neoload')
+
 from commands.login import cli as login
 from commands.status import cli as status
 from commands.config import cli as config
 from tests.helpers.test_utils import mock_login_get_urls
 
-import sys
 
-sys.path.append('neoload')
 __default_random_token = '12345678912345678901ae6d8af6abcdefabcdefabcdef'
 __default_api_url = 'https://neoload-web-api.neotys.perfreleng.org/'
 
@@ -46,7 +48,7 @@ def neoload_login(request, monkeypatch):
     makelivecalls = request.config.getoption('--makelivecalls')
     if makelivecalls:
         CliRunner().invoke(config, ["set", "status.resolvenames=True"])
-        CliRunner().invoke(config, ["set", "docker.zone=xWbV4"])
+        CliRunner().invoke(config, ["set", "docker.zone=kcNc7"])
 
     runner = CliRunner()
     result_status = runner.invoke(status)
